import logging

from .util import run_op

logger = logging.getLogger(__name__)

class AptInterface:

    def __init__(self):
        pass 

    def update(self):
        op = "apt-get update"
        logger.info(f"Updating apt: {op}")
        run_op(op)

    def upgrade(self):
        op = "apt-get -y upgrade"
        logger.info(f"Upgrading via apt: {op}")
        run_op(op)

    def install_packages(self, packages: list):
        packages_str = " ".join(packages)
        op = f"apt-get install -y {packages_str}"
        logger.info(f"Installing packages: {op}")
        run_op(op)
   

class PackageManager:

    def __init__(self):
        self.apt = AptInterface()

    def update(self):
        self.apt.update()

    def upgrade(self):
        self.update()
        self.apt.upgrade()

    def install_packages(self, packages: list):
        self.apt.install_packages(packages)
